@@ -89,7 +89,7 @@ def handle_db_id(data_dict: dict) -> dict:
                 data_dict['_id'] = data_dict['id']
             del data_dict['id']
         # 处理批量操作时，字符串类型ID问题
-        if isinstance(data_dict['_id'], dict):  # id是列表
+        if data_dict.__contains__('_id') and isinstance(data_dict['_id'], dict):  # 判断存在_id，并且值为字典则做特殊处理
             for key, value in data_dict['_id'].items():
                 if isinstance(value, list):  # 查找ID是列表
                     for i in range(len(value)):
